@@ -595,9 +595,21 @@ void ConfDockWidget::on_COAskypaPushButton_clicked()
     QDir dir(sciencedir);
     if (!dir.exists()) return;
 
+    int testChip = -1;
+    for (int chip=0; chip<mainGUI->instData.numChips; ++chip) {
+        if (!mainGUI->instData.badChips.contains(chip)) {
+            testChip = chip;
+            break;
+        }
+    }
+    if (testChip == -1) {
+        qDebug() << __func__ << "error: no data left after filtering";
+    }
+
+
     QString currentStatus = mainGUI->status.getStatusFromHistory();
-    QStringList filter1("*_1"+currentStatus+".fits");
-    QStringList filter2("*_1"+currentStatus+".sub.fits");
+    QStringList filter1("*_"+QString::number(testChip+1)+currentStatus+".fits");
+    QStringList filter2("*_"+QString::number(testChip+1)+currentStatus+".sub.fits");
     dir.setNameFilters(filter1);
     dir.setSorting(QDir::Name);
     QStringList list = dir.entryList();
@@ -658,6 +670,28 @@ void ConfDockWidget::on_COAskypaPushButton_clicked()
             && !cd21.isEmpty()
             && !cd22.isEmpty()) {
         double skyPA = getPosAnglefromCD(cd11.toDouble(), cd12.toDouble(), cd21.toDouble(), cd22.toDouble());   // in [deg]
+        skyPA *= -1.;     // it appears I need that, at least for:
+        /*
+         *  these data require a -1 prefactor
+    GSAOI.Ks.2013-05-22T06:50:58.5_1.head:CD1_1   =   2.069880636041E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_1.head:CD1_2   =  -5.020554295263E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_1.head:CD2_1   =   4.995016509429E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_1.head:CD2_2   =   2.197139027629E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_2.head:CD1_1   =   2.133359158630E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_2.head:CD1_2   =  -5.029786624776E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_2.head:CD2_1   =   5.142047608929E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_2.head:CD2_2   =   2.185105945141E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_3.head:CD1_1   =   2.113575793537E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_3.head:CD1_2   =  -5.089493103124E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_3.head:CD2_1   =   5.144032585776E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_3.head:CD2_2   =   2.028047913328E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_4.head:CD1_1   =   2.060624347989E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_4.head:CD1_2   =  -5.091430845254E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_4.head:CD2_1   =   4.999641460896E-06 / Linear projection matrix
+    GSAOI.Ks.2013-05-22T06:50:58.5_4.head:CD2_2   =   2.040364194243E-06 / Linear projection matrix
+        */
+
+
         // Truncate the result to one digit
         QString skyPAstring = QString::number(skyPA, 'f', 1);
         ui->COAskypaLineEdit->setText(skyPAstring);
@@ -691,7 +725,7 @@ void ConfDockWidget::on_skyAreaPushButton_clicked()
     QMessageBox msgBox;
     msgBox.setText("Use the middle mouse button (click and drag) to select one or more empty sky areas. "
                    "You can use the forward / backward buttons to select other images. Close the viewer when finished.\n\n"
-                   "Alternatively, you can open any astrometrically calibrated image in iView, e.g. a previous coaddition of the same data. "
+                   "Alternatively, you can click on any image in the memory viewer, or open any astrometrically calibrated image in iView, e.g. a previous coaddition of the same data. "
                    "Select the dropper tool at the upper left and then use the middle mouse button as explained above.");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.exec();
@@ -720,7 +754,7 @@ void ConfDockWidget::on_skyAreaPushButton_clicked()
     launchViewer("SkyMode");
 }
 
-//void ConfDockWidget::launchViewer(const QString &dirname, const QString &filter, const QString &mode)
+// void ConfDockWidget::launchViewer(const QString &dirname, const QString &filter, const QString &mode)
 void ConfDockWidget::launchViewer(const QString &mode)
 {
     // Load the plot viewer
@@ -734,9 +768,9 @@ void ConfDockWidget::launchViewer(const QString &mode)
     QString mainDirName = mainGUI->controller->mainDirName;
     QString scienceDirName = mainGUI->controller->DT_SCIENCE[0]->subDirName;
     QString dirName = mainDirName + "/"+scienceDirName;
-    IView *iView = new IView("MEMview", mainGUI->controller->DT_SCIENCE[0]->myImageList[0], dirName, this);
+    IView *iView = new IView("MEMview", mainGUI->controller->DT_SCIENCE[0]->myImageList[mainGUI->instData.validChip], dirName, this);
     iView->scene->clear();
-    MyImage *it = mainGUI->controller->DT_SCIENCE[0]->myImageList[0][0];
+    MyImage *it = mainGUI->controller->DT_SCIENCE[0]->myImageList[mainGUI->instData.validChip][0];
     iView->loadFromRAM(it, 3);
     iView->currentId = 0;
     // IView needs to know the directory name so that it can overlay catalogs
