@@ -60,7 +60,7 @@ ImageStatistics::ImageStatistics(QList<Data*> &datalist, const QString main, con
 
     ui->scienceComboBox->setCurrentText(sciencedirname);
 
-    Data *scienceData = getData(dataList, sciencedirname);            // dataList corresponds to DT_SCIENCE in the Controller class
+    scienceData = getData(dataList, sciencedirname);            // dataList corresponds to DT_SCIENCE in the Controller class
     scienceData->populateExposureList();
     myExposureList = scienceData->exposureList;
 
@@ -124,7 +124,6 @@ Data* ImageStatistics::getData(QList<Data *> DT_x, QString dirName)
 
 void ImageStatistics::makeConnections()
 {
-
     numericThresholdList << ui->skyMinLineEdit << ui->skyMaxLineEdit
                          << ui->airmassMinLineEdit << ui->airmassMaxLineEdit
                          << ui->seeingMinLineEdit << ui->seeingMaxLineEdit
@@ -163,6 +162,7 @@ void ImageStatistics::clearAll()
     statisticsDataDisplayed = false;
 }
 
+// clicking on "update images"
 void ImageStatistics::on_statisticsPushButton_clicked()
 {
     if (!scienceDir.exists()) {
@@ -183,19 +183,22 @@ void ImageStatistics::on_statisticsPushButton_clicked()
     }
 
     filteredImageList.clear();
+    filteredMyImages.clear();
     // Filter for sky coordinates
     QString ra = ui->raLineEdit->text();
     QString dec = ui->decLineEdit->text();
 
     for (int k=0; k<allMyImages.length(); ++k) {
-        if (isImageSelected(allMyImages[k], ra, dec, chipID)) filteredImageList << allMyImages[k]->chipName;
+        if (isImageSelected(allMyImages[k], ra, dec, chipID)) {
+            filteredImageList << allMyImages[k]->chipName;
+            filteredMyImages << allMyImages[k];
+        }
     }
 
     numObj = filteredImageList.size();
     if (numObj == 0) {
         QMessageBox::warning( this, "No images found",
-                              "No images found, check the directory path\n"
-                              "and, if provided, your name filter or sky coordinates.\n");
+                              "No images found, check chip filter or sky coordinates if provided.\n");
         ui->statisticsPushButton->setEnabled(true);
         ui->statisticsPushButton->setText("Get statistics ...");
         return;
@@ -204,6 +207,13 @@ void ImageStatistics::on_statisticsPushButton_clicked()
     readStatisticsData();
 
     plot();
+
+    // Push the filtered list of images to iView
+    if (iViewOpen) {
+        iView->myImageList = filteredMyImages;
+        iView->numImages = numObj;
+        iView->clearAll();
+    }
 }
 
 
@@ -386,6 +396,7 @@ void ImageStatistics::on_exportPushButton_clicked()
     }
 }
 
+// "Clicking on "display images"
 void ImageStatistics::on_showPushButton_clicked()
 {
     if (!scienceDir.exists()) return;
@@ -398,55 +409,64 @@ void ImageStatistics::on_showPushButton_clicked()
     if (ui->showPushButton->isChecked() && !iViewOpen) {
         if (!imgSelected && !statisticsDataDisplayed) {
             iView = new IView("FITSmonochrome", scienceDirName, "*.fits", this);
-            iView->show();
-            //            iView->clearAll();
+            connect(this, &ImageStatistics::imageSelected, iView, &IView::loadFITSexternalRAM);
+            connect(iView, &IView::destroyed, this, &ImageStatistics::uncheckIviewPushButton);
+            connect(iView, &IView::closed, this, &ImageStatistics::uncheckIviewPushButton);
+            connect(iView, &IView::currentlyDisplayedIndex, this, &ImageStatistics::iviewNewImageShownReceiver);
+            // iView->clearAll();
         }
         else if (!imgSelected && statisticsDataDisplayed) {
-            QCPDataRange range(0,1);
-            selection.addDataRange(range);
-            imgSelectedName = dataName[0];
-            imgSelected = true;
+//            QCPDataRange range(0,1);
+//            selection.addDataRange(range);
+//            imgSelectedName = dataName[0];
+//            imgSelected = true;
+            imgSelected = false;
             lastButtonClicked = Qt::LeftButton;
-            plotSelection(0);
-            iView = new IView("MEMview", allMyImages, scienceDirName, this); // dirname is needed to overlay catalogs
-            iViewOpen = true;
+//            plotSelection(0);
+//            iView = new IView("MEMview", allMyImages, scienceDirName, this); // dirname is needed to overlay catalogs
+            iView = new IView("MEMview", filteredMyImages, scienceDirName, this); // dirname is needed to overlay catalogs
+            connect(this, &ImageStatistics::imageSelected, iView, &IView::loadFITSexternalRAM);
+            connect(iView, &IView::destroyed, this, &ImageStatistics::uncheckIviewPushButton);
+            connect(iView, &IView::closed, this, &ImageStatistics::uncheckIviewPushButton);
+            connect(iView, &IView::currentlyDisplayedIndex, this, &ImageStatistics::iviewNewImageShownReceiver);
             // To be implemented
-            //            connect(iView, &IView::currentlyDisplayedIndex, this, &ImageStatistics::currentlyDisplayedIndexReceived);
+            // connect(iView, &IView::currentlyDisplayedIndex, this, &ImageStatistics::currentlyDisplayedIndexReceived);
             iView->scene->clear();
-            iView->show();
         }
         else {
             if (lastDataPointClicked != -1) {
-                iView = new IView("MEMview", allMyImages, scienceDirName, this); // dirname is needed to overlay catalogs
-                iView->loadFromRAM(allMyImages[lastDataPointClicked], 0);   // '0' refers to dataCurrent
+//                iView = new IView("MEMview", allMyImages, scienceDirName, this); // dirname is needed to overlay catalogs
+                iView = new IView("MEMview", filteredMyImages, scienceDirName, this); // dirname is needed to overlay catalogs
+                connect(this, &ImageStatistics::imageSelected, iView, &IView::loadFITSexternalRAM);
+                connect(iView, &IView::destroyed, this, &ImageStatistics::uncheckIviewPushButton);
+                connect(iView, &IView::closed, this, &ImageStatistics::uncheckIviewPushButton);
+                connect(iView, &IView::currentlyDisplayedIndex, this, &ImageStatistics::iviewNewImageShownReceiver);
+//                iView->loadFromRAM(allMyImages[lastDataPointClicked], 0);   // '0' refers to dataCurrent (compared to backup levels L1-L3)
+                iView->loadFromRAM(filteredMyImages[lastDataPointClicked], 0);   // '0' refers to dataCurrent (compared to backup levels L1-L3)
                 iView->currentId = lastDataPointClicked;
-                iView->show();
-            }
-            else {
-                qDebug() << "QDEBUG: ImageStatistics::on_showPushButton_clicked(): BUG: invalid selection";
             }
         }
+
+        bool sourcecatShown = iView->sourcecatSourcesShown;
+        bool refcatShown = iView->refcatSourcesShown;
+        iView->clearItems();
+        iView->setCatalogOverlaysExternally(sourcecatShown, refcatShown);
+        iView->redrawSkyCirclesAndCats();
+        iView->show();
         iViewOpen = true;
-        connect(this, &ImageStatistics::imageSelected, iView, &IView::loadFITSexternalRAM);
     }
     else if (ui->showPushButton->isChecked() && iViewOpen) {
-        iView->show();
-        connect(this, &ImageStatistics::imageSelected, iView, &IView::loadFITSexternalRAM);
-        iView->raise();
-        iViewOpen = true;
+        iView->scene->clear();
+        iViewOpen = false;
     }
-
-    // "uncheck" the iView PushButton when the viewer is closed externally
-    connect(iView, &IView::closed, this, &ImageStatistics::uncheckIviewPushButton);
 }
 
 // To be implemented
-/*
 void ImageStatistics::currentlyDisplayedIndexReceived(int currentId)
 {
+    qDebug() << currentId;
     // indicate displayed image, e.g. by a ring around the data point
 }
-*/
 
 void ImageStatistics::on_ClearPlotPushButton_clicked()
 {
@@ -522,9 +542,51 @@ void ImageStatistics::on_scienceComboBox_activated(const QString &arg1)
     scienceDirName = mainDir + "/" + arg1;
     scienceDir.setPath(scienceDirName);
 
-    Data *scienceData = getData(dataList, arg1);            // dataList corresponds to DT_SCIENCE in the Controller class
+    scienceData = getData(dataList, arg1);            // dataList corresponds to DT_SCIENCE in the Controller class
     scienceData->populateExposureList();
     myExposureList = scienceData->exposureList;
 
     init();
 }
+
+void ImageStatistics::on_chipsLineEdit_editingFinished()
+{
+    on_statisticsPushButton_clicked();
+}
+
+void ImageStatistics::on_raLineEdit_editingFinished()
+{
+    on_statisticsPushButton_clicked();
+}
+
+void ImageStatistics::on_decLineEdit_editingFinished()
+{
+    on_statisticsPushButton_clicked();
+}
+
+void ImageStatistics::activationChangedReceiver()
+{
+    // has no effect. in readStatisticsData()->makeListofBadImages(), images are recognized as bad even when they are not.
+    scienceData = getData(dataList, ui->scienceComboBox->currentText());
+    scienceData->populateExposureList();
+    myExposureList = scienceData->exposureList;
+
+    allMyImages.clear();
+     for (int k=0; k<myExposureList.length(); ++k) {
+         for (int chip=0; chip<instData->numChips; ++chip) {
+             if (instData->badChips.contains(chip)) continue;
+             auto &it = myExposureList[k][chip];
+             it->loadHeader();       // if not yet in memory
+             it->getMode(true);
+             allMyImages.append(it);
+         }
+     }
+
+     on_statisticsPushButton_clicked();
+}
+
+void ImageStatistics::iviewNewImageShownReceiver(int newDataPoint)
+{
+    lastDataPointClicked = newDataPoint;
+    highlightClickedDataPoint();
+}
