@@ -182,6 +182,8 @@ MainWindow::MainWindow(QString pid, QWidget *parent) :
     connect(controller, &Controller::scienceDataDirUpdated, this, &MainWindow::scienceDataDirUpdatedReceived);
     connect(controller, &Controller::updateMemoryProgressBar, this, &MainWindow::updateMemoryProgressBarReceived);
     connect(controller, &Controller::forceFinish, this, &MainWindow::taskFinished);
+    connect(controller, &Controller::refreshMemoryViewer, this, &MainWindow::refreshMemoryViewerReceiver);
+
     connect(this, &MainWindow::resetErrorStatus, controller, &Controller::resetErrorStatusReceived);
     connect(this, &MainWindow::rereadScienceDataDir, controller, &Controller::rereadScienceDataDirReceived);
     connect(this, &MainWindow::newProjectLoaded, controller, &Controller::newProjectLoadedReceived);
@@ -1521,6 +1523,8 @@ void MainWindow::load_dialog_imageStatistics()
     }
 
     ImageStatistics *imagestatistics = new ImageStatistics(controller->DT_SCIENCE, mainDir, scienceData->subDirName, &instData, this);
+    // Inform image statistics when the user manually (de)activates an image. Must be connected here, as imagestatistics does not know about mainGUI
+    connect(memoryViewer, &MemoryViewer::activationChanged, imagestatistics, &ImageStatistics::activationChangedReceiver);
     imagestatistics->show();
 }
 
@@ -1900,6 +1904,12 @@ void MainWindow::on_actionAcknowledging_triggered()
     acknowledging->show();
 }
 
+void MainWindow::on_actionDocumentation_triggered()
+{
+    tutorials = new Tutorials(this);
+    tutorials->show();
+}
+
 int MainWindow::estimateBinningFactor()
 {
     QScreen *screen = QGuiApplication::primaryScreen();
