@@ -289,6 +289,12 @@ void MyImage::readImage(QString loadFileName)
     }
 }
 
+bool MyImage::isActive()
+{
+    if (activeState == MyImage::ACTIVE) return true;
+    else return false;
+}
+
 // When having to read from a backup file right after launch (task repeated)
 void MyImage::readImageBackupL1Launch()
 {
@@ -371,18 +377,25 @@ bool MyImage::scanAstromHeader(int chip, QString mode)
     QFile file;
     if (mode == "inBackupDir") {
         file.setFileName(path+"/.origheader_backup/"+rootName+"_"+QString::number(chip+1)+".origastrom.head");
-        if(!file.open(QIODevice::ReadOnly)) {
-            emit messageAvailable("MyImage::scanAstromHeader(): " + file.fileName() + " " + file.errorString(), "error");
-            emit critical();
+        if (!file.open(QIODevice::ReadOnly)) {
+       //     emit messageAvailable("MyImage::scanAstromHeader(): " + file.fileName() + " " + file.errorString(), "error");
+       //     emit critical();
+            emit messageAvailable(baseName + ": origastrom.head not found, image deactivated", "warning");
+            if (*verbosity >= 2) emit messageAvailable(file.fileName() + ": " + file.errorString() + ", image deactivated", "warning");
+            setActiveState(MyImage::NOASTROM);
             return false;
         }
     }
     else {
         // mode == "inHeadersDir"
         file.setFileName(path+"/headers/"+rootName+"_"+QString::number(chip+1)+".head");
-        if(!file.open(QIODevice::ReadOnly)) {
-            emit messageAvailable("MyImage::scanAstromHeader(): " + file.fileName() + " " + file.errorString(), "error");
-            emit critical();
+        if (!file.open(QIODevice::ReadOnly)) {
+//            emit messageAvailable("MyImage::scanAstromHeader(): " + file.fileName() + " " + file.errorString(), "error");
+//            emit critical();
+            emit messageAvailable(baseName + ": .head not found, image deactivated", "warning");
+            if (*verbosity >= 2) emit messageAvailable(file.fileName() + " " + file.errorString() + ", image deactivated", "warning");
+            setActiveState(MyImage::NOASTROM);
+//            emit critical();
             return false;
         }
     }
@@ -853,7 +866,7 @@ void MyImage::applyBackgroundModel(const MyImage *backgroundImage, QString mode,
         }
 
         // No normalization of saturation keyword required
-//        saturationValue /= backgroundImage->skyValue;
+        //        saturationValue /= backgroundImage->skyValue;
         updateHeaderValue("SATURATE", saturationValue);
 
         QString img = " IMG = "+QString::number(skyValue, 'f', 3) + ";";
@@ -1213,6 +1226,7 @@ void MyImage::updateInactivePath()
     else if (activeState == MyImage::INACTIVE) pathExtension = "/inactive/";
     else if (activeState == MyImage::BADSTATS) pathExtension = "/inactive/badStatistics/";
     else if (activeState == MyImage::BADBACK) pathExtension = "/inactive/badBackground/";
+    else if (activeState == MyImage::NOASTROM) pathExtension = "/inactive/noAstrometry/";
     else if (activeState == MyImage::LOWDETECTION) pathExtension = "/inactive/lowDetections/";
     else if (activeState == MyImage::DELETED) pathExtension = "/inactive/";
 }
@@ -1578,13 +1592,14 @@ void MyImage::setActiveState(active_type state)
 
     // If the file is currently inactive, check whether the processing state is the same as that of currently active images.
     // Otherwise, the file must not be moved
+    // Check done externally before calling setActiveState()
+    /*
     if (state == MyImage::INACTIVE) {
         if (processingStatus->statusString != processingStatus->whatIsStatusOnDrive()) {
-
+        //
         }
     }
-
-
+    */
 
     // Move the image accordingly
     QString currentPath = path + pathExtension;      // The path where the image is currently located (if on disk)
@@ -1592,7 +1607,6 @@ void MyImage::setActiveState(active_type state)
     QString newPath = path + pathExtension;          // The path where the image should go
     if (!imageOnDrive) return;
     moveFile(baseName+".fits", currentPath, newPath);
-    // TODO: must do a modelUpdate
 }
 
 void MyImage::printCfitsioError(QString funcName, int status)
