@@ -140,6 +140,7 @@ public:
         INACTIVE,         // Image is inactive (for whatever reason, parked in inactive/)
         BADSTATS,         // Image was flagged as having bad seeing/ throughput etc (parked in inactive/badStatistics/)
         BADBACK,          // Image was flagged because the background could not be modeled (parked in inactive/badBackground/)
+        NOASTROM,         // Image was flagged because astrometric information could not be found
         LOWDETECTION,     // Image was flagged because it has insufficiently many source detections for astrometry
         DELETED,          // Image was manually deleted by the user (cannot be found anymore on disk)
     };
@@ -352,7 +353,7 @@ public:
     //  void subtractPolynomialSkyFit(gsl_vector *c, int order);
     void add(float value);
     void addExludedRegionToMask(long imin, long imax, long jmin, long jmax);
-    void appendToScampCatalogInternal(fitsfile *fptr, QString minFWHM_string, QString maxFlag_string);
+    void appendToScampCatalogInternal(fitsfile *fptr, QString minFWHM_string, QString maxFlag_string, bool empty = false);
     void appendToScampCatalogSourceExtractor(fitsfile *fptr);
     void applyBackgroundModel(const MyImage *backgroundImage, QString mode, bool rescaleFlag);
     void applyMask();
@@ -403,6 +404,7 @@ public:
     void initFITS(fitsfile **fptr, QString loadFileName, int *status);
     void initWCS();
     void initWeightfromGlobalWeight(const QList<MyImage *> &gwList);
+    bool isActive();
     void laplaceFilter(QVector<float> &dataFiltered);
     bool loadData(QString loadFileName = "");
     bool loadDataThreadSafe(QString loadFileName = "");
