@@ -169,6 +169,12 @@ Controller::~Controller()
 // Reads whatever is defined in the Setup data tree section, and maps it onto the various lists
 void Controller::mapDataTree()
 {
+    if (QDir(mainDirName) == QDir::home()) {
+        emit messageAvailable("For safety reasons, your home directory is not permitted as the main directory.", "error");
+        criticalReceived();
+        return;
+    }
+
     dataTreeUpdateOngoing = true;
     omp_set_lock(&memoryLock);
     emit clearMemoryView();
@@ -236,6 +242,11 @@ void Controller::parseDataDir(QLineEdit *le, QList<Data *> &DT_x)
             DT_x.clear();
             return;
         }
+        if (QDir(mainDirName) == QDir::home()) {
+            emit messageAvailable("For safety reasons, your home directory is not permitted as the main directory.", "error");
+            criticalReceived();
+            return;
+        }
 
         Data *data = new Data(instData, mask, mainDirName, it, &verbosity);
         connect(data, &Data::statusChanged, mainGUI, &MainWindow::statusChangedReceived);
@@ -948,7 +959,8 @@ Data* Controller::getData(QList<Data *> DT_x, QString dirName)
         if (QDir::cleanPath(it->dirName) == QDir::cleanPath(mainDirName + "/" + dirName)) {
             // check if it contains mastercalib data
             it->checkPresenceOfMasterCalibs();
-            return it;
+            if (it->isEmpty()) return nullptr;
+            else return it;
         }
     }
 
