@@ -217,7 +217,7 @@ public:
     void restoreRAWDATA();
     bool checkStatusConsistency();
     void emitStatusChanged();
-    bool hasMatchingPartnerFiles(QString testDirName, QString suffix);
+    bool hasMatchingPartnerFiles(QString testDirName, QString suffix, bool abort = true);
     bool checkTaskRepeatStatus(QString taskBasename);
     void resetStaticModel();
     void writeBackgroundModel(const int &chip, const QString &mode, const QString &basename, bool &staticImageWritten);
@@ -232,6 +232,8 @@ public:
     bool doesCoaddContainRaDec(const QString &refRA, const QString &refDEC);
     void unprotectMemoryForBackground(int chip);
     void checkModeIsPresent();
+    bool isEmpty();
+
 public slots:
     void setMemoryLockReceived(bool locked);
     void setWCSLockReceived(bool locked);
