@@ -54,7 +54,8 @@ void Controller::populateHeaderDictionary()
                                        "HIERARCH ESO INS FILT3 NAME", "HIERARCH ESO INS FILT4 NAME",
                                        "HIERARCH ESO INS OPTI-2 NAME",
                                        "AFT", "ALFLTNM", "FAFLTNM", "FBFLTNM", "FILTRE", "FLTRNAME", "PFMFNAME", "WFFBAND",
-                                       "ACAMFSLI", "ACAMWH1", "ACAMWH2", "INGF1NAM", "INGF2NAM", "LIRF1NAM", "LIRF2NAM"});
+                                       "ACAMFSLI", "ACAMWH1", "ACAMWH2", "INGF1NAM", "INGF2NAM", "LIRF1NAM", "LIRF2NAM",
+                                       "NCFLTNM1", "NCFLTNM2"});
 
     // Other keywords of interest (to calculate others, or preserve information)
     headerDictionary.insert("INSTRUME", {"INSTRUME", "DETECTOR"});
@@ -306,6 +307,7 @@ void Controller::populateInstrumentDictionary()
     instrumentDictionary.insert("GMOS-S-EEV@GEMINI", "GMOS-S");
     instrumentDictionary.insert("GMOS-S-HAM@GEMINI", "GMOS-S");
     instrumentDictionary.insert("GMOS-S-HAM_1x1@GEMINI", "GMOS-S");
+    instrumentDictionary.insert("GMOS-S-HAM_4x4@GEMINI", "GMOS-S");
     instrumentDictionary.insert("GMOS-S_EEV_GeMS@GEMINI", "GMOS-S");
     instrumentDictionary.insert("GOODMAN_1x1@SOAR", "");
     instrumentDictionary.insert("GOODMAN_2x2@SOAR", "");
@@ -384,6 +386,7 @@ void Controller::populateInstrumentDictionary()
     instrumentDictionary.insert("PAUCam@WHT", "");
     instrumentDictionary.insert("PFC_new@WHT", "");
     instrumentDictionary.insert("PFC_old@WHT", "Prime Imaging");
+    instrumentDictionary.insert("PF_QHY2x2", "QHY CCD QHY600M-929ba64");
     instrumentDictionary.insert("PICCD@WISE", "");
     instrumentDictionary.insert("PISCES@LBT", "");
     instrumentDictionary.insert("PISCO@LCO", "PISCO");
