@@ -61,6 +61,16 @@ void Controller::taskInternalCoaddition()
     mjdEnd = 0.;
     mjdMedian = 0.;
 
+    // If coming here right after launch:
+    // #pragma omp parallel for num_threads(maxExternalThreads)
+    for (int chip=0; chip<instData->numChips; ++chip) {
+        for (auto &it : coaddScienceData->myImageList[chip]) {
+            it->loadHeader();
+        }
+    }
+
+    coaddScienceData->checkModeIsPresent();
+
     memoryDecideDeletableStatus(coaddScienceData, false);
     QString coaddSubDir = "coadd_"+filterArg;
     QString coaddUniqueID = cdw->ui->COAuniqueidLineEdit->text();
@@ -70,9 +80,13 @@ void Controller::taskInternalCoaddition()
 
     if (!coaddScienceData->hasMatchingPartnerFiles(headerDirName, ".head")) return;
 
-    if (!coaddScienceData->doesCoaddContainRaDec(cdw->ui->COAraLineEdit->text(), cdw->ui->COAdecLineEdit->text())) {
-        emit showMessageBox("Controller::POOR_COORD", cdw->ui->COAraLineEdit->text(), cdw->ui->COAdecLineEdit->text());
-        return;
+    // if all chips are stacked, make sure the reference point is within the covered area.
+    // If selected chips are present, then the user might want  the same ref coords for all chip stacks, which might be outside
+    if (cdw->ui->COAchipsLineEdit->text().isEmpty()) {
+        if (!coaddScienceData->doesCoaddContainRaDec(cdw->ui->COAraLineEdit->text(), cdw->ui->COAdecLineEdit->text())) {
+            emit showMessageBox("Controller::POOR_COORD", cdw->ui->COAraLineEdit->text(), cdw->ui->COAdecLineEdit->text());
+            return;
+        }
     }
 
     //    qDebug() << "taskInternalCoaddition() : " << filterArg;
@@ -80,13 +94,7 @@ void Controller::taskInternalCoaddition()
     // TODO
     // The following is very fast and does not need a parallel loop on top.
 
-    // If coming here right after launch:
-    // #pragma omp parallel for num_threads(maxExternalThreads)
-    for (int chip=0; chip<instData->numChips; ++chip) {
-        for (auto &it : coaddScienceData->myImageList[chip]) {
-            it->loadHeader();
-        }
-    }
+    getMinimumSaturationValue();
 
     // The various coadd tasks are daisy-chained through signals and slots
     coaddSmoothEdge();
@@ -227,15 +235,15 @@ void Controller::coaddPrepare(QString filterArg)
     progress = 30.;
     //    emit progressUpdate(progress);
 
-    // For proper motion correction we need the MJD-OBS of the first exposure, taken from the first chip
+    // For proper motion correction we need the MJD-OBS of the first exposure, taken from the first valid chip
     // We also want accurate start and end DATE-OBS keywords.
     QVector<double> mjdobsData;
-    minDateObs = coaddScienceData->myImageList[0][0]->dateobs;
-    maxDateObs = coaddScienceData->myImageList[0][0]->dateobs;
-    mjdStart = coaddScienceData->myImageList[0][0]->mjdobs;
-    mjdEnd = coaddScienceData->myImageList[0][0]->mjdobs;
+    minDateObs = coaddScienceData->myImageList[instData->validChip][0]->dateobs;
+    maxDateObs = coaddScienceData->myImageList[instData->validChip][0]->dateobs;
+    mjdStart = coaddScienceData->myImageList[instData->validChip][0]->mjdobs;
+    mjdEnd = coaddScienceData->myImageList[instData->validChip][0]->mjdobs;
     float lastExpTime = 0.; // to be added to DATE-OBS of the last exposure
-    for (auto &it : coaddScienceData->myImageList[0]) {
+    for (auto &it : coaddScienceData->myImageList[instData->validChip]) {
         if (!it->successProcessing) continue;
         it->loadHeader();
         mjdobsData.append(it->mjdobs);
@@ -250,8 +258,8 @@ void Controller::coaddPrepare(QString filterArg)
         }
     }
     double mjdobsZero = minVec_T(mjdobsData);
-//    mjdStart = mjdobsZero;
-//    mjdEnd = maxVec_T(mjdobsData) + lastExpTime / 86400.;
+    //    mjdStart = mjdobsZero;
+    //    mjdEnd = maxVec_T(mjdobsData) + lastExpTime / 86400.;
     mjdEnd += lastExpTime / 86400.;
     mjdMedian = straightMedian_T(mjdobsData, 0, false);
     bool doPMupdate = false;
@@ -338,7 +346,7 @@ void Controller::coaddPrepare(QString filterArg)
     connect(workerThreadPrepare, &QThread::started, swarpWorker, &SwarpWorker::runSwarp, Qt::DirectConnection);
     //    connect(workerThreadPrepare, &QThread::finished, workerThreadPrepare, &QThread::deleteLater, Qt::DirectConnection);
     connect(workerThreadPrepare, &QThread::finished, workerThreadPrepare, &QThread::deleteLater);
-    connect(swarpWorker, &SwarpWorker::errorFound, this, &Controller::errorFoundReceived);
+    connect(swarpWorker, &SwarpWorker::errorFound, this, &Controller::swarpErrorFoundReceived);
     connect(swarpWorker, &SwarpWorker::finishedPreparation, this, &Controller::finishedPreparationReceived);
     // MUST NOT connect to quit, otherwise control returns immediately to the controller, which might start another coaddition
     // right away in case of multi-color data
@@ -358,7 +366,7 @@ void Controller::coaddPrepare(QString filterArg)
 }
 
 
-void Controller::errorFoundReceived()
+void Controller::swarpErrorFoundReceived()
 {
     successProcessing = false;
 }
@@ -492,14 +500,13 @@ void Controller::coaddPrepareProjectRotation()
         if (line.contains("CD2_2   =")) cd22_coadd = line.split("=")[1].split("/")[0].simplified().toDouble();
     }
 
-    // PA of the original data (taken from first image)
-
-    double cd11 = coaddScienceData->myImageList[0][0]->wcs->cd[0];
-    double cd12 = coaddScienceData->myImageList[0][0]->wcs->cd[1];
-    double cd21 = coaddScienceData->myImageList[0][0]->wcs->cd[2];
-    double cd22 = coaddScienceData->myImageList[0][0]->wcs->cd[3];
-    double PAold = -1. * getPosAnglefromCD(cd11, cd12, cd21, cd22);      // in [deg]; not sure about the minus here
-    double PAnew = cdw->ui->COAskypaLineEdit->text().toDouble();         // in [deg]; if image is flipped, the angle to get "parallel" axes should be 180 - the automatically determined angle.
+    // PA of the original data (taken from first image and its valid chip)
+    double cd11 = coaddScienceData->myImageList[instData->validChip][0]->wcs->cd[0];
+    double cd12 = coaddScienceData->myImageList[instData->validChip][0]->wcs->cd[1];
+    double cd21 = coaddScienceData->myImageList[instData->validChip][0]->wcs->cd[2];
+    double cd22 = coaddScienceData->myImageList[instData->validChip][0]->wcs->cd[3];
+    double PAold = getPosAnglefromCD(cd11, cd12, cd21, cd22);        // in [deg]; not sure about the minus here
+    double PAnew = cdw->ui->COAskypaLineEdit->text().toDouble();     // in [deg]; if image is flipped, the angle to get "parallel" axes should be 180 - the automatically determined angle.
 
     rotateCDmatrix(cd11_coadd, cd12_coadd, cd21_coadd, cd22_coadd, PAnew);
     long naxis1New = 0;
@@ -563,7 +570,7 @@ void Controller::coaddPrepareBuildSwarpCommand(QString refRA, QString refDE)
     QString coaddSize = "";
     QString naxis1 = cdw->ui->COAsizexLineEdit->text();
     QString naxis2 = cdw->ui->COAsizeyLineEdit->text();
-    if (!naxis1.isEmpty() && !naxis2.isEmpty()) coaddSize = "-IMAGE_SIZE "+naxis1+","+naxis2;
+    if (!naxis1.isEmpty() && !naxis2.isEmpty()) coaddSize = " -IMAGE_SIZE "+naxis1+","+naxis2;
 
     QString pixelScale = cdw->ui->COApixscaleLineEdit->text();
     if (pixelScale.isEmpty()) pixelScale = QString::number(instData->pixscale, 'f', 9);
@@ -759,7 +766,7 @@ void Controller::coaddResample()
         }
         connect(workerThreads[i], &QThread::started, swarpWorkers[i], &SwarpWorker::runSwarp);
         connect(workerThreads[i], &QThread::finished, workerThreads[i], &QThread::deleteLater);
-        connect(swarpWorkers[i], &SwarpWorker::errorFound, this, &Controller::errorFoundReceived);
+        connect(swarpWorkers[i], &SwarpWorker::errorFound, this, &Controller::swarpErrorFoundReceived);
         //        connect(workerThreads[i], &QThread::finished, workerThreads[i], &QThread::deleteLater);
         connect(swarpWorkers[i], &SwarpWorker::finishedResampling, this, &Controller::waitForResamplingThreads);
         //       connect(swarpWorkers[i], &SwarpWorker::finished, workerThreads[i], &QThread::quit);
@@ -823,6 +830,7 @@ void Controller::coaddSwarpfilter()
     swarpFilter.progress = &progress;
     connect(&swarpFilter, &SwarpFilter::messageAvailable, monitor, &Monitor::displayMessage);
     connect(&swarpFilter, &SwarpFilter::progressUpdate, mainGUI, &MainWindow::progressUpdateReceived);
+    connect(&swarpFilter, &SwarpFilter::critical, this, &Controller::criticalReceived);
     swarpFilter.runCosmicFilter();
 
     // TODO: introduce successProcessing to swarpfilter();
@@ -898,7 +906,7 @@ void Controller::coaddCoaddition()
     connect(swarpWorker, &SwarpWorker::finishedCoaddition, this, &Controller::coaddUpdate, Qt::DirectConnection);
     connect(swarpWorker, &SwarpWorker::finished, workerThreadCoadd, &QThread::quit);
     connect(swarpWorker, &SwarpWorker::finished, swarpWorker, &QObject::deleteLater);
-    connect(swarpWorker, &SwarpWorker::errorFound, this, &Controller::errorFoundReceived);
+    connect(swarpWorker, &SwarpWorker::errorFound, this, &Controller::swarpErrorFoundReceived);
     //connect(swarpWorker, &SwarpWorker::finished, workerThreadCoadd, &QThread::quit);
     //connect(swarpWorker, &SwarpWorker::finished, swarpWorker, &QObject::deleteLater);
     connect(swarpWorker, &SwarpWorker::messageAvailable, monitor, &Monitor::displayMessage);
@@ -960,7 +968,7 @@ void Controller::coaddUpdate()
     bool skippedIQ = true;
     float seeing_world = 0.;
     float seeing_image = 0.;
-    float maxVal = 100.;
+    //    float maxVal = 100.;
 
     emit loadViewer(coaddDirName, "coadd.fits", "DragMode");
 
@@ -985,7 +993,8 @@ void Controller::coaddUpdate()
         coadd->weightName = "coadd";
         coadd->readWeight();
         coadd->gain = 1.0;
-        maxVal = maxVec_T(coadd->dataCurrent);
+        coadd->saturationValue = minCoaddSaturationValue;
+        //        maxVal = maxVec_T(coadd->dataCurrent);
         float radius = sqrt(coadd->naxis1*coadd->naxis1 + coadd->naxis2*coadd->naxis2) / 2. * coadd->plateScale / 60.;   // in arcmin
         // Enforce an upper limit to the download catalog (the query also has a built-in limit of # sources < 1e6)
         if (radius > 60) radius = 60.;
@@ -1012,8 +1021,8 @@ void Controller::coaddUpdate()
             // match
             static_cast<void> (imageQuality->getSeeingFromGaia());
             //        if (!gaia) imageQuality->getSeeingFromRhMag();      TODO: not yet implemented
-            seeing_world = imageQuality->fwhm;                           // in arcsec
-            seeing_image = imageQuality->fwhm / coadd->plateScale;       // in pixel
+            seeing_image = imageQuality->fwhm;                           // in pixel
+            seeing_world = imageQuality->fwhm * coadd->plateScale;       // in pixel
             if (imageQuality->numSources > 0) {
                 emit messageAvailable("coadd.fits : FWHM = " + QString::number(seeing_world, 'f', 2) + "\"  ("
                                       + QString::number(seeing_image, 'f', 2) + " pixel)", "image");
@@ -1031,9 +1040,6 @@ void Controller::coaddUpdate()
                 emit messageAvailable("Undersampling detected. The chosen "+cdw->ui->COAkernelComboBox->currentText()
                                       +" resampling kernel could lead to artifacts in compact sources (stars). In this case, consider the LANCZOS2 kernel.", "warning");
             }
-            else {
-                skippedIQ = true;
-            }
             coadd->releaseAllDetectionMemory();
             coadd->releaseBackgroundMemory("entirely");
         }
@@ -1080,9 +1086,9 @@ void Controller::coaddUpdate()
     fits_update_key_flt(fptr, "EXPTIME", 1.0, 1, "Exposure time is normalized to 1s", &status);
     fits_update_key_flt(fptr, "TEXPTIME", coaddTexptime, 3, "Total exposure time [s]", &status);
     fits_update_key_flt(fptr, "SKYVALUE", coaddSkyvalue, 3, "Effective background value [e-/s]", &status);
-    fits_update_key_flt(fptr, "GAIN", coaddGain, 3, "Effective gain", &status);
+    fits_update_key_flt(fptr, "GAIN", coaddGain, 3, "Effective gain. This image is already in e-/s!", &status);
     fits_update_key_str(fptr, "UNITS", "e-/s", "Pixels are photo-electrons / second", &status);
-    fits_update_key_flt(fptr, "SATURATE", 1000., 3, "Currently undetermined (e-)", &status);
+    fits_update_key_flt(fptr, "SATURATE", minCoaddSaturationValue, 3, "Lowest value at which saturation occurs [e-/s]", &status);
     if (!skippedIQ) {
         fits_update_key_flt(fptr, "FWHM_I", seeing_image, 3, "FWHM (pixel)", &status);
         fits_update_key_flt(fptr, "FWHM_W", seeing_world, 3, "FWHM (arcsec)", &status);
@@ -1095,7 +1101,7 @@ void Controller::coaddUpdate()
     fits_update_key_str(fptr, "THELIRUN", mainGUI->ui->setupProjectLineEdit->text().toUtf8().data(), "THELI project name", &status);
     fits_close_file(fptr, &status);
 
-    printCfitsioError("coaddUpdate():", status);
+    printCfitsioError(__func__, status);
 
     emit progressUpdate(100);
 
@@ -1108,7 +1114,8 @@ void Controller::coaddUpdate()
     // Finally, do flux calibration if requested
     if (cdw->ui->COAfluxcalibCheckBox->isChecked()) {
         emit messageAvailable("coadd.fits : Loading flux calibration module ...", "image");
-        emit loadAbsZP(coaddDirName+"/coadd.fits", maxVal);
+        //        emit loadAbsZP(coaddDirName+"/coadd.fits", maxVal);
+        emit loadAbsZP(coaddDirName+"/coadd.fits", minCoaddSaturationValue);
     }
     else {
         // Now we can quit the first coaddition thread (which spawned all the other threads).
@@ -1117,6 +1124,25 @@ void Controller::coaddUpdate()
     }
 }
 
+void Controller::getMinimumSaturationValue()
+{
+    minCoaddSaturationValue = 1e12;
+
+    QList<MyImage*> allMyImages;
+    long numMyImages = makeListofAllImages(allMyImages, coaddScienceData);
+
+    // Update minimum saturation value (normalized to exposure time)
+    // TODO: update wrt fluxscaling
+    for (int k=0; k<numMyImages; ++k) {
+        if (abortProcess || !successProcessing) continue;
+        auto &it = allMyImages[k];
+        if (!it->successProcessing) continue;
+        if (it->saturationValue / it->exptime < minCoaddSaturationValue) {
+            minCoaddSaturationValue = it->saturationValue / it->exptime;
+        }
+    }
+}
+
 void Controller::absZeroPointCloseReceived()
 {
     workerThreadPrepare->quit();
