@@ -245,7 +245,7 @@ void Splitter::extractImages()
     // multiple readout channels in different FITS extensions
     multiChannelMultiExt << "DEIMOS_2AMP@KECK"
                          << "GMOS-N-HAM@GEMINI" << "GMOS-N-HAM_1x1@GEMINI"
-                         << "GMOS-S-HAM@GEMINI" << "GMOS-S-HAM_1x1@GEMINI"
+                         << "GMOS-S-HAM@GEMINI" << "GMOS-S-HAM_1x1@GEMINI" << "GMOS-S-HAM_4x4@GEMINI"
                          << "LRIS_BLUE@KECK" << "LRIS_RED@KECK"
                          << "MOSAIC-II_16@CTIO" << "MOSAIC-III_4@KPNO_4m"
                          << "PISCO@LCO" << "SAMI_2x2@SOAR" << "SOI@SOAR";
@@ -298,9 +298,11 @@ void Splitter::extractImagesFITS()
     while (rawStatus != END_OF_FILE && successProcessing) {
 
         if (hduType == IMAGE_HDU) {
-
-            // for MMIRS, we only want to keep the first extension
-            if (instData.name.contains("MMIRS") && chip >= 1) break;
+            // for MMIRS and NOTcam, we only want to keep the first extension
+            if (instData.name.contains("MMIRS")
+                    || instData.name.contains("NOTcam")) {
+                if (chip >= 1) break;
+            }
 
             // some multi-chip cams (FORS, etc) come with separate FITS files. For them, 'chip' would always be zero,
             // and thus the correct overscan regions etc not identified correctly.
@@ -831,7 +833,7 @@ void Splitter::getNumberOfAmplifiers()
     // multiple readout channels in different FITS extensions
     multiChannelMultiExt << "DEIMOS_2AMP@KECK"
                          << "GMOS-N-HAM@GEMINI" <<  "GMOS-N-HAM_1x1@GEMINI"
-                         << "GMOS-S-HAM@GEMINI" << "GMOS-S-HAM_1x1@GEMINI"
+                         << "GMOS-S-HAM@GEMINI" << "GMOS-S-HAM_1x1@GEMINI" << "GMOS-S-HAM_4x4@GEMINI"
                          << "LRIS_BLUE@KECK" << "LRIS_RED@KECK"
                          << "MOSAIC-II_16@CTIO" << "MOSAIC-III_4@KPNO_4m"
                          << "PISCO@LCO" << "SAMI_2x2@SOAR" << "SOI@SOAR";
@@ -1241,6 +1243,10 @@ void Splitter::writeImageSlice(int chip, long slice)
     for (int i=0; i<headerTHELI.length(); ++i) {
         fits_write_record(fptr, headerTHELI[i].toUtf8().constData(), &status);
     }
+
+    // Update the SATURATE keyword
+    fits_update_key_flt(fptr, "SATURATE", saturationValue, 6, nullptr, &status);
+
     // WARNING: POOR TIMIMG! Increment MJD-OBS by 0.1 s per slice
     double mjdobs = 0.;
     fits_read_key_dbl(fptr, "MJD-OBS", &mjdobs, NULL, &status);
@@ -1359,6 +1365,8 @@ void Splitter::readPrimaryHeader()
 
 bool Splitter::checkCorrectMaskSize(const int chip)
 {
+    if (instData.name.contains("DUMMY")) return true;
+
     long n_mask = mask->globalMask[chip].length();
     long n_data = dataCurrent.length();
     // detectors with multi-amps (one amp per FITS extension): masked at a later stage (calibration)
